@@ -27,37 +27,19 @@ Private Structures
 
 """
 
-# -----------------------------------------------------------------------------
-# :author:    Pete R. Jemian
-# :email:     jemian@anl.gov
-# :copyright: (c) 2017-2021, UChicago Argonne, LLC
-#
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
-#
-# The full license is in the file LICENSE.txt, distributed with this software.
-# -----------------------------------------------------------------------------
-
 
 from collections import OrderedDict
-from ophyd.device import (
-    Device,
-    Component as Cpt,
-    DynamicDeviceComponent as DDC,
-    FormattedComponent as FC,
-)
-from ophyd import EpicsSignal, EpicsSignalRO
+from ophyd import Device
+from ophyd import Component as Cpt
+from ophyd import DynamicDeviceComponent as DDC
+from ophyd import FormattedComponent as FC
+from ophyd import EpicsSignal
+from ophyd import EpicsSignalRO
 from ophyd.status import DeviceStatus
-from ophyd.ophydobj import Kind
 
 from .. import utils as APS_utils
 
 
-__all__ = """
-    SscanRecord
-    SscanDevice
-    """.split()
-
-
 class sscanPositioner(Device):
     """
     positioner of an EPICS sscan record
@@ -71,41 +53,23 @@ class sscanPositioner(Device):
 
     """
 
-    readback_pv = FC(
-        EpicsSignal, "{self.prefix}.R{self._ch_num}PV", kind=Kind.config
-    )
-    readback_value = FC(EpicsSignalRO, "{self.prefix}.R{self._ch_num}CV")
+    readback_pv = FC(EpicsSignal, "{self.prefix}.R{self._ch_num}PV", kind="config")
+    readback_value = FC(EpicsSignalRO, "{self.prefix}.R{self._ch_num}CV", kind="hinted")
     array = FC(
-        EpicsSignalRO, "{self.prefix}.P{self._ch_num}CA", kind=Kind.omitted
-    )
-    setpoint_pv = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}PV", kind=Kind.config
-    )
-    setpoint_value = FC(EpicsSignalRO, "{self.prefix}.P{self._ch_num}DV")
-    start = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}SP", kind=Kind.config
-    )
-    center = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}CP", kind=Kind.config
-    )
-    end = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}EP", kind=Kind.config
-    )
-    step_size = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}SI", kind=Kind.config
-    )
-    width = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}WD", kind=Kind.config
-    )
-    abs_rel = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}AR", kind=Kind.config
-    )
-    mode = FC(
-        EpicsSignal, "{self.prefix}.P{self._ch_num}SM", kind=Kind.config
-    )
-    units = FC(
-        EpicsSignalRO, "{self.prefix}.P{self._ch_num}EU", kind=Kind.config
+        EpicsSignalRO,
+        "{self.prefix}.P{self._ch_num}CA",
+        kind="normal",  # TODO: which kind here?
     )
+    setpoint_pv = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}PV", kind="config")
+    setpoint_value = FC(EpicsSignalRO, "{self.prefix}.P{self._ch_num}DV", kind="normal")
+    start = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}SP", kind="config")
+    center = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}CP", kind="config")
+    end = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}EP", kind="config")
+    step_size = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}SI", kind="config")
+    width = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}WD", kind="config")
+    abs_rel = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}AR", kind="config")
+    mode = FC(EpicsSignal, "{self.prefix}.P{self._ch_num}SM", kind="config")
+    units = FC(EpicsSignalRO, "{self.prefix}.P{self._ch_num}EU", kind="config")
 
     def __init__(self, prefix, num, **kwargs):
         self._ch_num = num
@@ -142,13 +106,9 @@ class sscanDetector(Device):
 
     """
 
-    input_pv = FC(
-        EpicsSignal, "{self.prefix}.D{self._ch_num}PV", kind=Kind.config
-    )
-    current_value = FC(EpicsSignal, "{self.prefix}.D{self._ch_num}CV")
-    array = FC(
-        EpicsSignal, "{self.prefix}.D{self._ch_num}CA", kind=Kind.omitted
-    )
+    input_pv = FC(EpicsSignal, "{self.prefix}.D{self._ch_num}PV", kind="config")
+    current_value = FC(EpicsSignal, "{self.prefix}.D{self._ch_num}CV", kind="hinted")
+    array = FC(EpicsSignal, "{self.prefix}.D{self._ch_num}CA", kind="omitted")
 
     def __init__(self, prefix, num, **kwargs):
         self._ch_num = num
@@ -175,10 +135,8 @@ class sscanTrigger(Device):
         ~reset
     """
 
-    trigger_pv = FC(
-        EpicsSignal, "{self.prefix}.T{self._ch_num}PV", kind=Kind.config
-    )
-    trigger_value = FC(EpicsSignal, "{self.prefix}.T{self._ch_num}CD")
+    trigger_pv = FC(EpicsSignal, "{self.prefix}.T{self._ch_num}PV", kind="config")
+    trigger_value = FC(EpicsSignal, "{self.prefix}.T{self._ch_num}CD", kind="config")
 
     def __init__(self, prefix, num, **kwargs):
         self._ch_num = num
@@ -233,42 +191,40 @@ class SscanRecord(Device):
 
     """
 
-    desc = Cpt(EpicsSignal, ".DESC", kind=Kind.config)
-    scan_phase = Cpt(EpicsSignalRO, ".FAZE")
-    data_state = Cpt(EpicsSignalRO, ".DSTATE")
-    data_ready = Cpt(EpicsSignalRO, ".DATA")
-    scan_busy = Cpt(EpicsSignalRO, ".BUSY")
-    alert_flag = Cpt(EpicsSignalRO, ".ALRT")
-    alert_message = Cpt(EpicsSignalRO, ".SMSG")
-    number_points = Cpt(EpicsSignal, ".NPTS", kind=Kind.config)
-    maximum_number_points = Cpt(EpicsSignal, ".MPTS", kind=Kind.config)
-    current_point = Cpt(EpicsSignalRO, ".CPT")
-    pasm = Cpt(EpicsSignal, ".PASM")
-    execute_scan = Cpt(EpicsSignal, ".EXSC")
-    bspv = Cpt(EpicsSignal, ".BSPV", kind=Kind.config)
-    bscd = Cpt(EpicsSignal, ".BSCD")
-    bswait = Cpt(EpicsSignal, ".BSWAIT")
-    cmnd = Cpt(EpicsSignal, ".CMND")
-    detector_delay = Cpt(EpicsSignal, ".DDLY")
-    positioner_delay = Cpt(EpicsSignal, ".PDLY")
-    reference_detector = Cpt(EpicsSignal, ".REFD", kind=Kind.config)
-    wait = Cpt(EpicsSignal, ".WAIT")
-    wcnt = Cpt(EpicsSignalRO, ".WCNT")
-    awct = Cpt(EpicsSignal, ".AWCT")
-    acqt = Cpt(EpicsSignal, ".ACQT")
-    acqm = Cpt(EpicsSignal, ".ACQM")
-    atime = Cpt(EpicsSignal, ".ATIME")
-    copyto = Cpt(EpicsSignal, ".COPYTO")
-    a1pv = Cpt(EpicsSignal, ".A1PV", kind=Kind.config)
-    a1nv = Cpt(EpicsSignal, ".A1NV", kind=Kind.config)
-    a1cd = Cpt(EpicsSignal, ".A1CD")
-    aspv = Cpt(EpicsSignal, ".ASPV", kind=Kind.config)
-    ascd = Cpt(EpicsSignal, ".ASCD")
+    desc = Cpt(EpicsSignal, ".DESC", kind="config")
+    scan_phase = Cpt(EpicsSignalRO, ".FAZE", kind="config")
+    data_state = Cpt(EpicsSignalRO, ".DSTATE", kind="config")
+    data_ready = Cpt(EpicsSignalRO, ".DATA", kind="config")
+    scan_busy = Cpt(EpicsSignalRO, ".BUSY", kind="config")
+    alert_flag = Cpt(EpicsSignalRO, ".ALRT", kind="config")
+    alert_message = Cpt(EpicsSignalRO, ".SMSG", kind="config")
+    number_points = Cpt(EpicsSignal, ".NPTS", kind="config")
+    maximum_number_points = Cpt(EpicsSignal, ".MPTS", kind="config")
+    current_point = Cpt(EpicsSignalRO, ".CPT", kind="normal")
+    pasm = Cpt(EpicsSignal, ".PASM", kind="config")
+    execute_scan = Cpt(EpicsSignal, ".EXSC", kind="omitted")
+    bspv = Cpt(EpicsSignal, ".BSPV", kind="config")
+    bscd = Cpt(EpicsSignal, ".BSCD", kind="omitted")
+    bswait = Cpt(EpicsSignal, ".BSWAIT", kind="omitted")
+    cmnd = Cpt(EpicsSignal, ".CMND", kind="omitted")
+    detector_delay = Cpt(EpicsSignal, ".DDLY", kind="config")
+    positioner_delay = Cpt(EpicsSignal, ".PDLY", kind="config")
+    reference_detector = Cpt(EpicsSignal, ".REFD", kind="config")
+    wait = Cpt(EpicsSignal, ".WAIT", kind="config")
+    wcnt = Cpt(EpicsSignalRO, ".WCNT", kind="config")
+    awct = Cpt(EpicsSignal, ".AWCT", kind="config")
+    acqt = Cpt(EpicsSignal, ".ACQT", kind="config")
+    acqm = Cpt(EpicsSignal, ".ACQM", kind="config")
+    atime = Cpt(EpicsSignal, ".ATIME", kind="config")
+    copyto = Cpt(EpicsSignal, ".COPYTO", kind="config")
+    a1pv = Cpt(EpicsSignal, ".A1PV", kind="config")
+    a1nv = Cpt(EpicsSignal, ".A1NV", kind="config")
+    a1cd = Cpt(EpicsSignal, ".A1CD", kind="config")
+    aspv = Cpt(EpicsSignal, ".ASPV", kind="config")
+    ascd = Cpt(EpicsSignal, ".ASCD", kind="config")
 
     positioners = DDC(_sscan_positioners("1 2 3 4".split()))
-    detectors = DDC(
-        _sscan_detectors(APS_utils.itemizer("%02d", range(1, 71)))
-    )
+    detectors = DDC(_sscan_detectors(APS_utils.itemizer("%02d", range(1, 71))))
     triggers = DDC(_sscan_triggers("1 2 3 4".split()))
 
     def set(self, value, **kwargs):
@@ -325,15 +281,17 @@ class SscanRecord(Device):
         """
         for part in (self.positioners, self.detectors, self.triggers):
             channel_names = []  # part.get_configured_channels()
+            # fmt: off
             channel_names = [
                 ch
                 for ch in part.component_names
                 if getattr(part, ch).defined_in_EPICS
             ]
+            # fmt: on
 
             part.configuration_attrs = channel_names
             part.read_attrs = channel_names
-            part.kind = Kind.normal
+            part.kind = "normal"
 
     @property
     def defined_in_EPICS(self):
@@ -347,7 +305,7 @@ class SscanRecord(Device):
 
 class SscanDevice(Device):
     """
-    synApps XXX IOC setup of sscan records: ``$(P):scan$(N)``
+    EPICS synApps XXX IOC setup of sscan records: ``$(P):scan$(N)``
 
     .. index:: Ophyd Device; synApps SscanDevice
 
@@ -358,15 +316,15 @@ class SscanDevice(Device):
 
     """
 
-    scan_dimension = Cpt(EpicsSignalRO, "ScanDim")
-    scan_pause = Cpt(EpicsSignal, "scanPause")
-    abort_scans = Cpt(EpicsSignal, "AbortScans")
+    scan_dimension = Cpt(EpicsSignalRO, "ScanDim", kind="config")
+    scan_pause = Cpt(EpicsSignal, "scanPause", kind="omitted")
+    abort_scans = Cpt(EpicsSignal, "AbortScans", kind="omitted")
     scan1 = Cpt(SscanRecord, "scan1")
     scan2 = Cpt(SscanRecord, "scan2")
     scan3 = Cpt(SscanRecord, "scan3")
     scan4 = Cpt(SscanRecord, "scan4")
     scanH = Cpt(SscanRecord, "scanH")
-    resume_delay = Cpt(EpicsSignal, "scanResumeSEQ.DLY1")
+    resume_delay = Cpt(EpicsSignal, "scanResumeSEQ.DLY1", kind="config")
 
     def reset(self):
         """set all fields to default values"""
@@ -384,3 +342,13 @@ class SscanDevice(Device):
                 continue
             attrs.append(nm)
         self.read_attrs = attrs
+
+# -----------------------------------------------------------------------------
+# :author:    Pete R. Jemian
+# :email:     jemian@anl.gov
+# :copyright: (c) 2017-2022, UChicago Argonne, LLC
+#
+# Distributed under the terms of the Argonne National Laboratory Open Source License.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+# -----------------------------------------------------------------------------
